@@ -919,7 +919,7 @@ main (int argc, char **argv)
                      "unless you plan on hacking on it.\n"
                      "\n"
                      "Use the raw Xlib version of Dali Clock\n"
-                     "instead: http://www.jwz.org/xdaliclock/\n"
+                     "instead: https://www.jwz.org/xdaliclock/\n"
                      "\n"));
   }
 
@@ -932,7 +932,7 @@ static void
 usage (void)
 {
   fprintf (stderr, "\n%s\n\
-                  http://www.jwz.org/xdaliclock/\n\n\
+                  https://www.jwz.org/xdaliclock/\n\n\
 usage: %s [ options ]\n\
 where options include\n\
 \n\
